================
Python SnowFlake
================

A library that provides snowflake features to python, including Client and Server. 
You will not need to

This is extend of https://github.com/koblas/pysnowflake with Client adding.


See `documentations <http://pysnowflake.readthedocs.org/en/latest/>`_

